// ---------------------------------------------------------------------------
// xHUD.cs -- Version 2.4 -- December 31, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Display your current zoom level (very unobtrusively) in a small HUD
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\xHUD.cs", "2.4", "Lorne Laliberte", "Dec 31, 2000");

include("writer\\bitmap_strings.cs");
include("writer\\event.cs");
include("writer\\save.cs");
include("writer\\whud.cs");
include("writer\\you_died.cs");
include("writer\\you_respawned.cs");
include("writer\\you_spawned.cs");
include("writer\\zoom.cs", novol);

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_xHUD.cs file

    // Screen coordinates for xHUD
    $xHUD::X = "r:xhair+5";
    $xHUD::Y = "50%";

    // Screen coordinates for xHUD when the xhair.cs rangefinder is active
    $xHUD::rangeX = "r:xhair+5";
    $xHUD::rangeY = "50%";

    // Default text colour, from 0 to 2 (ignored if bitmaps are used)
    $xHUD::textColour = "1";

    // Make the xHUD background transparent
    $xHUD::Transparent = "true";

    // Use the tiny red or green text bitmaps I've designed instead of the
    // normal Tribes font
    $xHUD::useBitmaps = "true";

    // Use outline bitmaps (black background) -- use "2" if you want to force
    // the outline for red bitmaps, otherwise only green bitmaps will have the
    // black background (I find it easier to read that way)
    $xHUD::useOutlineBitmaps = "true";

    // Default bitmap colour -- can be either "green" or "red"
    $xHUD::bitmapColour = "green";

    // How much extra padding you would like between each bitmap character
    $xHUD::letterPadding = "0";

    // Right-justify the xHUD contents
    $xHUD::rightJustify = "true";

    // Prefix (like "Zoom: " or something) -- ignored if bitmaps are used
    $xHUD::prefix = "";

    // Width in pixels -- make sure this is wide enough for the contents
    $xHUD::width = "21";

    // Cycle through available colours -- does nothing if bitmaps are used
    //bind(keyboard0, make, alt, "whatever", TO, "xHUD::nextColour();");

// ---------------------------------------------------------------------------

WriterPrefs::load("xHUD");

$xHUD::ColourText[0] = "<f0>";
$xHUD::ColourText[1] = "<f1>";
$xHUD::ColourText[2] = "<f2>";


function xHUD::nextColour()
{
    if($xHUD::useBitmaps)
    {
        if(!String::ICompare($xHUD::bitmapColour, green))
            $xHUD::bitmapColour = red;
        else
            $xHUD::bitmapColour = green;
    }
    else
    {
        $xHUD::textColour++;
        if($xHUD::textColour > 2)
            $xHUD::textColour = 0;
    }
    wHUD::update(xHUD, xHUD::text());
}


function xHUD::height()
{
    if($xHUD::transparent && $xHUD::useBitmaps)
        return $xHUD::height = 9;
    else
        return $xHUD::height = 18;
}

function xHUD::text()
{
    if($xHUD::useBitmaps)
    {
        return $xHUD::currentText = getBitmapStr($zoom::mag[$zoom::level] @ "<x1>x", $xHUD::bitmapColour, $xHUD::rightJustify, 0, 0, $xHUD::letterPadding, "", false, $xHUD::useOutlineBitmaps);
    }
    else
    {
        $xHUD::currentText = wif($xHUD::rightJustify, "<jr>", "") @ $xHUD::ColourText[$xHUD::textColour] @ $xHUD::prefix @ $zoom::mag[$zoom::level] @ "x";
        if((%width = getStrPixels($xHUD::currentText)) > $xHUD::width)
            $xHUD::width = %width;
        return $xHUD::currentText;
    }
}


function xHUD::onYouSpawned()
{
    // Build xHUD on first weapon switch, after playGui exists
    if(!wHUD::exists(xHUD))
    {
        wHUD::makeMoveable(1, 1, 0, xHUD, $xHUD::x, $xHUD::y, $xHUD::width + wif(!$xHUD::transparent && !$xHUD::useBitmaps, 6, 0), xHUD::height(), $xHUD::transparent, true, xHUD::text(), wif(!$xHUD::transparent && !$xHUD::useBitmaps, 3, ""));
    }
    else
    {
        wHUD::show(xHUD);
    }
    return;
}

function xHUD::relocate()
{
    wHUD::makeMoveable(1, 1, 0, xHUD, $xHUD::x, $xHUD::y, $xHUD::width + wif(!$xHUD::transparent && !$xHUD::useBitmaps, 6, 0), xHUD::height(), $xHUD::transparent, true, $xHUD::currentText, wif(!$xHUD::transparent && !$xHUD::useBitmaps, 3, ""));
    return;
}


function onHudMove_xHUD(%x, %y, %width, %height)
{
    $xHUD::x = %x;
    $xHUD::y = %y;
    $xHUD::width = %width;
    wHUD::makeMoveable(1, 1, 0, xHUD, $xHUD::x, $xHUD::y, $xHUD::width + wif(!$xHUD::transparent && !$xHUD::useBitmaps, 6, 0), xHUD::height(), $xHUD::transparent, true, $xHUD::currentText, wif(!$xHUD::transparent && !$xHUD::useBitmaps, 3, ""));

    if(String::findSubStr($xHUD::x @ $xHUD::y @ $xHUD::width, "xhair") != -1)
        Event::Attach(eventXhairDimensionsChanged, "xHUD::onXhairDimensionsChanged();");

    return;
}


function xHUD::onZoomChanged(%mag)
{
    wHUD::update(xHUD, xHUD::text());
    return;
}


// Update xHUD position if xhair became wider or taller, just in case a position relative to xhair was used
function xHUD::onXhairDimensionsChanged()
{
    wHUD::makeMoveable(1, 1, 0, xHUD, $xHUD::x, $xHUD::y, $xHUD::width + wif(!$xHUD::transparent && !$xHUD::useBitmaps, 6, 0), xHUD::height(), $xHUD::transparent, true, $xHUD::currentText, wif(!$xHUD::transparent && !$xHUD::useBitmaps, 3, ""));
}


function xHUD::onRangeFinderOn()
{
    if(($xHUD::x == $xHUD::rangeX) && ($xHUD::y == $xHUD::rangeY))
        return;

    wHUD::makeMoveable(1, 1, 0, xHUD, $xHUD::x, $xHUD::y, $xHUD::width + wif(!$xHUD::transparent && !$xHUD::useBitmaps, 6, 0), xHUD::height(), $xHUD::transparent, true, $xHUD::currentText, wif(!$xHUD::transparent && !$xHUD::useBitmaps, 3, ""));
}


function xHUD::onRangeFinderOff()
{
    if(($xHUD::x == $xHUD::rangeX) && ($xHUD::y == $xHUD::rangeY))
        return;

    wHUD::makeMoveable(1, 1, 0, xHUD, $xHUD::x, $xHUD::y, $xHUD::width + wif(!$xHUD::transparent && !$xHUD::useBitmaps, 6, 0), xHUD::height(), $xHUD::transparent, true, $xHUD::currentText, wif(!$xHUD::transparent && !$xHUD::useBitmaps, 3, ""));
}


function xHUD::save()
{
    AddExportText("    // Screen coordinates for xHUD");
    ExportSetting("    $xHUD::X", "r:xhair+5", "", "5 pixels right of the xhair reticle");
    ExportSetting("    $xHUD::Y", "50%");
    AddExportText("");
    AddExportText("    // Screen coordinates for xHUD when the xhair.cs rangefinder is active");
    ExportSetting("    $xHUD::rangeX", "r:xhair+5", "", "5 pixels right of the xhair reticle");
    ExportSetting("    $xHUD::rangeY", "50%");
    AddExportText("");
    AddExportText("    // Default text colour, from 0 to 2 (ignored if bitmaps are used)");
    ExportSetting("    $xHUD::textColour", 1);
    AddExportText("");
    AddExportText("    // Make the xHUD background transparent");
    ExportSetting("    $xHUD::Transparent", true);
    AddExportText("");
    AddExportText("    // Use the tiny red or green text bitmaps I've designed instead of the");
    AddExportText("    // normal Tribes font");
    ExportSetting("    $xHUD::useBitmaps", true);
    AddExportText("");
    AddExportText("    // Use outline bitmaps (black background) -- use \"2\" if you want to force");
    AddExportText("    // the outline for red bitmaps, otherwise only green bitmaps will have the");
    AddExportText("    // black background (I find it easier to read that way)");
    ExportSetting("    $xHUD::useOutlineBitmaps", true);
    AddExportText("");
    AddExportText("    // Default bitmap colour -- can be either \"green\" or \"red\"");
    ExportSetting("    $xHUD::bitmapColour", "green");
    AddExportText("");
    AddExportText("    // How much extra padding you would like between each bitmap character");
    ExportSetting("    $xHUD::letterPadding", 0);
    AddExportText("");
    AddExportText("    // Right-justify the xHUD contents");
    ExportSetting("    $xHUD::rightJustify", true);
    AddExportText("");
    AddExportText("    // Prefix (like \"Zoom: \" or something) -- ignored if bitmaps are used");
    ExportSetting("    $xHUD::prefix", "");
    AddExportText("");
    AddExportText("    // Width in pixels -- make sure this is wide enough for the contents");
    ExportSetting("    $xHUD::width", 21);
    AddExportText("");
    AddExportText("    // Cycle through available colours -- does nothing if bitmaps are used");

    ExportBind("xHUD::nextColour();", "//bind(keyboard0, make, alt, \"whatever\", TO, \"xHUD::nextColour();\");");
}

WriterPrefs::save("xHUD");

function xHUD::init()
{
    needs("writer\\xHUD.cs", "writer\\bitmap_strings.cs 1.2",
                             "writer\\event.cs 2.7",
                             "writer\\save.cs 2.3",
                             "writer\\wHUD.cs 1.2",
                             "writer\\you_died.cs 1.6",
                             "writer\\you_respawned.cs 1.2",
                             "writer\\you_spawned.cs 1.1",
                             "writer\\zoom.cs 4.2");

    // Reset zoom level upon joining a game
    Event::Attach(eventZoomChanged, xHUD::onZoomChanged);
    Event::Attach(eventRangeFinderOn, "xHUD::onRangeFinderOn();");
    Event::Attach(eventRangeFinderOn, "xHUD::onRangeFinderOff();");

    if(String::findSubStr($xHUD::x @ $xHUD::y @ $xHUD::width, "xhair") != -1)
        Event::Attach(eventXhairDimensionsChanged, "xHUD::onXhairDimensionsChanged();");

    Event::Attach(eventYouSpawned, "xHUD::onYouSpawned();");
    Event::Attach(eventYouRespawned, "wHUD::show(xHUD);");
    Event::Attach(eventChangeMission, "wHUD::hide(xHUD);");
    Event::Attach(eventScreenModeChanged, "xHUD::relocate();");
    Event::Attach(eventScreenSizeChanged, "xHUD::relocate();");
    Event::Attach(wHudMoved, "xHUD::relocate();");
    Event::Attach(wHudMove_xHUD, onHudMove_xHUD);
    Event::Attach(wHudSave_xHUD, "WriterPrefs::save(\"xHUD\");");
}
Event::Attach(writerInit, "xHUD::init();");

if(!$UsingWriterLoader) xHUD::init();
